@@ -3,7 +3,7 @@ package Data::Hopen::G::Link;
 use strict;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000017';
 
 use parent 'Data::Hopen::G::Runnable';
 use Class::Tiny {
@@ -33,6 +33,9 @@ Copy the inputs to the outputs.
 
 The output is C<{}> if no inputs are provided.
 
+By default, the output is a copy of the inputs
+(see L<Data::Hopen::G::Runnable/passthrough>).
+
 =cut
 
 sub _run {
