@@ -4,8 +4,9 @@ package Data::Hopen::Scope::Environment;
 use strict;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000017';
 
+use Data::Hopen::Scope qw(:default :internal);
 use parent 'Data::Hopen::Scope';
 
 use Data::Hopen qw(hlog getparameters);
@@ -34,17 +35,6 @@ Note: L<Data::Hopen::Scope/merge> is unsupported.
 
 ### Protected functions ###
 
-# Don't support -set, but permit `-set=>0` for the sake of code calling
-# through the Scope interface.  Call as `_set0($set)`.
-# Returns truthy of OK, falsy if not.
-# Better a readily-obvious crash than a subtle bug!
-sub _set0 {
-    $_[0] //= 0;    # Give the caller a default set
-    my $set = shift;
-    return false if defined($set) && $set ne '0' && $set ne '*';
-    return true;
-} #_set0()
-
 =head2 _find_here
 
 Find a named data item in C<%ENV> and return it.  Returns undef on
