@@ -1,11 +1,11 @@
 # Data::Hopen::Scope::Hash - a hash-based nested key-value store based
-# TODO handle $set == FIRST_ONLY
 package Data::Hopen::Scope::Hash;
 use strict;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000017';
 
+use Data::Hopen::Scope qw(:default :internal);
 use parent 'Data::Hopen::Scope';
 use Class::Tiny {
     _content => sub { +{} },    # Our storage
@@ -16,7 +16,6 @@ use Data::Hopen qw(getparameters);
 use Set::Scalar;
 #use Sub::ScopeFinalizer qw(scope_finalizer);
 
-
 # Docs {{{1
 
 =head1 NAME
@@ -46,29 +45,19 @@ Not used, but provided so you can use L<Data::Hopen/hnew> to make Scopes.
 
 # }}}1
 
-# Don't support -set, but permit `-set=>0` for the sake of code calling
-# through the Scope interface.  Call as `_set0($set)`.
-# Returns truthy of OK, falsy if not.
-# Better a readily-obvious crash than a subtle bug!
-sub _set0 {
-    $_[0] //= 0;    # Give the caller a default set
-    my $set = shift;
-    return false if defined($set) && $set ne '0' && $set ne '*';
-    return true;
-} #_set0()
-
 =head2 put
 
 Add key-value pairs to this scope.  See L<Data::Hopen::Scope/put>.  In this
 particular implementation, the last-added value for a particular key wins.
 
-TODO add $set option
+TODO add $set option once it's added to D::H::Scope::put().
 
 =cut
 
 sub put {
     my $self = shift or croak 'Need an instance';
     croak "Got an odd number of parameters" if @_%2;
+    return $self unless @_;
     my %new = @_;
     @{$self->_content}{keys %new} = values %new;
     return $self;
@@ -83,8 +72,9 @@ Merge in values.  See L<Data::Hopen::Scope/merge>.
 sub merge {
     my $self = shift or croak 'Need an instance';
     croak "Got an odd number of parameters" if @_%2;
-    my %new = @_;
+    return unless @_;
 
+    my %new = @_;
     my $merger = $self->_merger;
     $self->_content($merger->merge($self->_content, \%new));
 
