@@ -36,8 +36,6 @@ BEGIN { @EXPORT = qw(true false); }
 
 sub import {
     my ($target, $filename) = caller;
-    #my $pkg =
-               shift;   # Don't need our package name
 
     # Keep output lines in order
     STDOUT->autoflush(true);
@@ -56,6 +54,7 @@ sub import {
     };
 
     # --- Process argument list ----------------------------------------
+    shift;  # Don't need our package name any more
 
     # First argument: if a non-reference, the name of the package to load.
     if(@_ && $_[0] && !ref($_[0])) {
